==> cotrix-web-publish-0.1.0-20140409.014214-30.jar: org/cotrix/web/publish/shared/PublishMetadata.java <==
package org.cotrix.web.publish.shared;

import java.util.HashMap;
import java.util.Map;

import com.google.gwt.user.client.rpc.IsSerializable;

/**
 * @author "Federico De Faveri federico.defaveri@fao.org"
 *
 */
public class PublishMetadata implements IsSerializable {
	
	protected String originalName;
	protected String name;
	protected String version;
	protected boolean sealed;
	protected Map<String, String> attributes = new HashMap<String, String>();

	/**
	 * @return the originalName
	 */
	public String getOriginalName() {
		return originalName;
	}

	/**
	 * @param originalName the originalName to set
	 */
	public void setOriginalName(String originalName) {
		this.originalName = originalName;
	}

	/**
	 * @return the name
	 */
	public String getName() {
		return name;
	}
	
	/**
	 * @param name the name to set
	 */
	public void setName(String name) {
		this.name = name;
	}

	/**
	 * @return the version
	 */
	public String getVersion() {
		return version;
	}

	/**
	 * @param version the version to set
	 */
	public void setVersion(String version) {
		this.version = version;
	}

	/**
	 * @return the attributes
	 */
	public Map<String, String> getAttributes() {
		return attributes;
	}

	/**
	 * @param attributes the attributes to set
	 */
	public void setAttributes(Map<String, String> attributes) {
		this.attributes = attributes;
	}

	/**
	 * @return the sealed
	 */
	public boolean isSealed() {
		return sealed;
	}

	/**
	 * @param sealed the sealed to set
	 */
	public void setSealed(boolean sealed) {
		this.sealed = sealed;
	}

	/** 
	 * {@inheritDoc}
	 */
	@Override
	public String toString() {
		StringBuilder builder = new StringBuilder();
		builder.append("ImportMetadata [originalName=");
		builder.append(originalName);
		builder.append(", name=");
		builder.append(name);
		builder.append(", version=");
		builder.append(version);
		builder.append(", sealed=");
		builder.append(sealed);
		builder.append(", attributes=");
		builder.append(attributes);
		builder.append("]");
		return builder.toString();
	}
}

==> cotrix-web-publish-0.2.0-20140628.004530-4.jar: org/cotrix/web/publish/shared/PublishMetadata.java <==
package org.cotrix.web.publish.shared;

import java.util.HashMap;
import java.util.Map;

import org.cotrix.web.common.shared.codelist.UIQName;

import com.google.gwt.user.client.rpc.IsSerializable;

/**
 * @author "Federico De Faveri federico.defaveri@fao.org"
 *
 */
public class PublishMetadata implements IsSerializable {
	
	protected UIQName originalName;
	protected UIQName name;
	protected String version;
	protected boolean sealed;
	protected Map<String, String> attributes = new HashMap<String, String>();

	/**
	 * @return the originalName
	 */
	public UIQName getOriginalName() {
		return originalName;
	}

	/**
	 * @param originalName the originalName to set
	 */
	public void setOriginalName(UIQName originalName) {
		this.originalName = originalName;
	}

	/**
	 * @return the name
	 */
	public UIQName getName() {
		return name;
	}
	
	/**
	 * @param name the name to set
	 */
	public void setName(UIQName name) {
		this.name = name;
	}

	/**
	 * @return the version
	 */
	public String getVersion() {
		return version;
	}

	/**
	 * @param version the version to set
	 */
	public void setVersion(String version) {
		this.version = version;
	}

	/**
	 * @return the attributes
	 */
	public Map<String, String> getAttributes() {
		return attributes;
	}

	/**
	 * @param attributes the attributes to set
	 */
	public void setAttributes(Map<String, String> attributes) {
		this.attributes = attributes;
	}

	/**
	 * @return the sealed
	 */
	public boolean isSealed() {
		return sealed;
	}

	/**
	 * @param sealed the sealed to set
	 */
	public void setSealed(boolean sealed) {
		this.sealed = sealed;
	}

	/** 
	 * {@inheritDoc}
	 */
	@Override
	public String toString() {
		StringBuilder builder = new StringBuilder();
		builder.append("ImportMetadata [originalName=");
		builder.append(originalName);
		builder.append(", name=");
		builder.append(name);
		builder.append(", version=");
		builder.append(version);
		builder.append(", sealed=");
		builder.append(sealed);
		builder.append(", attributes=");
		builder.append(attributes);
		builder.append("]");
		return builder.toString();
	}
}
